# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKImageIntensityPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkClampImageFilterPython
else:
    import _itkClampImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkPointPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkInPlaceImageFilterAPython
import itk.itkImageToImageFilterBPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkImagePython
import itk.itkRGBPixelPython
import itk.itkImageRegionPython
import itk.itkRGBAPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkImageToImageFilterAPython

def itkClampImageFilterIF2IF2_Superclass_New():
    return itkClampImageFilterIF2IF2_Superclass.New()

class itkClampImageFilterIF2IF2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF2IF2):
    r"""Proxy of C++ itkClampImageFilterIF2IF2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIF2IF2_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF2IF2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIF2IF2_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF2IF2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::Clamp< float >
        GetFunctor(self) -> itk::Functor::Clamp< float > const &
        """
        return _itkClampImageFilterPython.itkClampImageFilterIF2IF2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::Clamp< float > const &

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF2IF2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIF2IF2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIF2IF2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF2IF2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIF2IF2_Superclass

        Create a new object of the class itkClampImageFilterIF2IF2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIF2IF2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIF2IF2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIF2IF2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIF2IF2_Superclass in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIF2IF2_Superclass_swigregister(itkClampImageFilterIF2IF2_Superclass)

def itkClampImageFilterIF2ISS2_Superclass_New():
    return itkClampImageFilterIF2ISS2_Superclass.New()

class itkClampImageFilterIF2ISS2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF2ISS2):
    r"""Proxy of C++ itkClampImageFilterIF2ISS2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIF2ISS2_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF2ISS2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIF2ISS2_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF2ISS2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::Clamp< float,short >
        GetFunctor(self) -> itk::Functor::Clamp< float,short > const &
        """
        return _itkClampImageFilterPython.itkClampImageFilterIF2ISS2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::Clamp< float,short > const &

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF2ISS2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIF2ISS2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIF2ISS2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF2ISS2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIF2ISS2_Superclass

        Create a new object of the class itkClampImageFilterIF2ISS2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIF2ISS2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIF2ISS2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIF2ISS2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIF2ISS2_Superclass in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIF2ISS2_Superclass_swigregister(itkClampImageFilterIF2ISS2_Superclass)

def itkClampImageFilterIF2IUC2_Superclass_New():
    return itkClampImageFilterIF2IUC2_Superclass.New()

class itkClampImageFilterIF2IUC2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF2IUC2):
    r"""Proxy of C++ itkClampImageFilterIF2IUC2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIF2IUC2_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF2IUC2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIF2IUC2_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF2IUC2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::Clamp< float,unsigned char >
        GetFunctor(self) -> itk::Functor::Clamp< float,unsigned char > const &
        """
        return _itkClampImageFilterPython.itkClampImageFilterIF2IUC2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::Clamp< float,unsigned char > const &

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF2IUC2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIF2IUC2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIF2IUC2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF2IUC2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIF2IUC2_Superclass

        Create a new object of the class itkClampImageFilterIF2IUC2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIF2IUC2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIF2IUC2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIF2IUC2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIF2IUC2_Superclass in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIF2IUC2_Superclass_swigregister(itkClampImageFilterIF2IUC2_Superclass)

def itkClampImageFilterIF3IF3_Superclass_New():
    return itkClampImageFilterIF3IF3_Superclass.New()

class itkClampImageFilterIF3IF3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF3IF3):
    r"""Proxy of C++ itkClampImageFilterIF3IF3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIF3IF3_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF3IF3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIF3IF3_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF3IF3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::Clamp< float >
        GetFunctor(self) -> itk::Functor::Clamp< float > const &
        """
        return _itkClampImageFilterPython.itkClampImageFilterIF3IF3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::Clamp< float > const &

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF3IF3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIF3IF3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIF3IF3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF3IF3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIF3IF3_Superclass

        Create a new object of the class itkClampImageFilterIF3IF3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIF3IF3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIF3IF3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIF3IF3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIF3IF3_Superclass in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIF3IF3_Superclass_swigregister(itkClampImageFilterIF3IF3_Superclass)

def itkClampImageFilterIF3ISS3_Superclass_New():
    return itkClampImageFilterIF3ISS3_Superclass.New()

class itkClampImageFilterIF3ISS3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF3ISS3):
    r"""Proxy of C++ itkClampImageFilterIF3ISS3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIF3ISS3_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF3ISS3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIF3ISS3_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF3ISS3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::Clamp< float,short >
        GetFunctor(self) -> itk::Functor::Clamp< float,short > const &
        """
        return _itkClampImageFilterPython.itkClampImageFilterIF3ISS3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::Clamp< float,short > const &

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF3ISS3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIF3ISS3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIF3ISS3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF3ISS3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIF3ISS3_Superclass

        Create a new object of the class itkClampImageFilterIF3ISS3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIF3ISS3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIF3ISS3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIF3ISS3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIF3ISS3_Superclass in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIF3ISS3_Superclass_swigregister(itkClampImageFilterIF3ISS3_Superclass)

def itkClampImageFilterIF3IUC3_Superclass_New():
    return itkClampImageFilterIF3IUC3_Superclass.New()

class itkClampImageFilterIF3IUC3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF3IUC3):
    r"""Proxy of C++ itkClampImageFilterIF3IUC3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIF3IUC3_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF3IUC3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIF3IUC3_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF3IUC3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::Clamp< float,unsigned char >
        GetFunctor(self) -> itk::Functor::Clamp< float,unsigned char > const &
        """
        return _itkClampImageFilterPython.itkClampImageFilterIF3IUC3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::Clamp< float,unsigned char > const &

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF3IUC3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIF3IUC3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIF3IUC3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF3IUC3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIF3IUC3_Superclass

        Create a new object of the class itkClampImageFilterIF3IUC3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIF3IUC3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIF3IUC3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIF3IUC3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIF3IUC3_Superclass in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIF3IUC3_Superclass_swigregister(itkClampImageFilterIF3IUC3_Superclass)

def itkClampImageFilterISS2IF2_Superclass_New():
    return itkClampImageFilterISS2IF2_Superclass.New()

class itkClampImageFilterISS2IF2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS2IF2):
    r"""Proxy of C++ itkClampImageFilterISS2IF2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterISS2IF2_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS2IF2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterISS2IF2_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS2IF2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::Clamp< short,float >
        GetFunctor(self) -> itk::Functor::Clamp< short,float > const &
        """
        return _itkClampImageFilterPython.itkClampImageFilterISS2IF2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::Clamp< short,float > const &

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS2IF2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterISS2IF2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterISS2IF2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS2IF2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterISS2IF2_Superclass

        Create a new object of the class itkClampImageFilterISS2IF2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterISS2IF2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterISS2IF2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterISS2IF2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterISS2IF2_Superclass in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterISS2IF2_Superclass_swigregister(itkClampImageFilterISS2IF2_Superclass)

def itkClampImageFilterISS2ISS2_Superclass_New():
    return itkClampImageFilterISS2ISS2_Superclass.New()

class itkClampImageFilterISS2ISS2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS2ISS2):
    r"""Proxy of C++ itkClampImageFilterISS2ISS2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterISS2ISS2_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS2ISS2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterISS2ISS2_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS2ISS2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::Clamp< short >
        GetFunctor(self) -> itk::Functor::Clamp< short > const &
        """
        return _itkClampImageFilterPython.itkClampImageFilterISS2ISS2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::Clamp< short > const &

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS2ISS2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterISS2ISS2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterISS2ISS2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS2ISS2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterISS2ISS2_Superclass

        Create a new object of the class itkClampImageFilterISS2ISS2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterISS2ISS2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterISS2ISS2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterISS2ISS2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterISS2ISS2_Superclass in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterISS2ISS2_Superclass_swigregister(itkClampImageFilterISS2ISS2_Superclass)

def itkClampImageFilterISS2IUC2_Superclass_New():
    return itkClampImageFilterISS2IUC2_Superclass.New()

class itkClampImageFilterISS2IUC2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS2IUC2):
    r"""Proxy of C++ itkClampImageFilterISS2IUC2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterISS2IUC2_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS2IUC2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterISS2IUC2_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS2IUC2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::Clamp< short,unsigned char >
        GetFunctor(self) -> itk::Functor::Clamp< short,unsigned char > const &
        """
        return _itkClampImageFilterPython.itkClampImageFilterISS2IUC2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::Clamp< short,unsigned char > const &

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS2IUC2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterISS2IUC2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterISS2IUC2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS2IUC2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterISS2IUC2_Superclass

        Create a new object of the class itkClampImageFilterISS2IUC2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterISS2IUC2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterISS2IUC2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterISS2IUC2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterISS2IUC2_Superclass in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterISS2IUC2_Superclass_swigregister(itkClampImageFilterISS2IUC2_Superclass)

def itkClampImageFilterISS3IF3_Superclass_New():
    return itkClampImageFilterISS3IF3_Superclass.New()

class itkClampImageFilterISS3IF3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS3IF3):
    r"""Proxy of C++ itkClampImageFilterISS3IF3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterISS3IF3_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS3IF3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterISS3IF3_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS3IF3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::Clamp< short,float >
        GetFunctor(self) -> itk::Functor::Clamp< short,float > const &
        """
        return _itkClampImageFilterPython.itkClampImageFilterISS3IF3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::Clamp< short,float > const &

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS3IF3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterISS3IF3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterISS3IF3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS3IF3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterISS3IF3_Superclass

        Create a new object of the class itkClampImageFilterISS3IF3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterISS3IF3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterISS3IF3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterISS3IF3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterISS3IF3_Superclass in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterISS3IF3_Superclass_swigregister(itkClampImageFilterISS3IF3_Superclass)

def itkClampImageFilterISS3ISS3_Superclass_New():
    return itkClampImageFilterISS3ISS3_Superclass.New()

class itkClampImageFilterISS3ISS3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS3ISS3):
    r"""Proxy of C++ itkClampImageFilterISS3ISS3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterISS3ISS3_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS3ISS3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterISS3ISS3_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS3ISS3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::Clamp< short >
        GetFunctor(self) -> itk::Functor::Clamp< short > const &
        """
        return _itkClampImageFilterPython.itkClampImageFilterISS3ISS3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::Clamp< short > const &

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS3ISS3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterISS3ISS3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterISS3ISS3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS3ISS3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterISS3ISS3_Superclass

        Create a new object of the class itkClampImageFilterISS3ISS3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterISS3ISS3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterISS3ISS3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterISS3ISS3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterISS3ISS3_Superclass in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterISS3ISS3_Superclass_swigregister(itkClampImageFilterISS3ISS3_Superclass)

def itkClampImageFilterISS3IUC3_Superclass_New():
    return itkClampImageFilterISS3IUC3_Superclass.New()

class itkClampImageFilterISS3IUC3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS3IUC3):
    r"""Proxy of C++ itkClampImageFilterISS3IUC3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterISS3IUC3_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS3IUC3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterISS3IUC3_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS3IUC3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::Clamp< short,unsigned char >
        GetFunctor(self) -> itk::Functor::Clamp< short,unsigned char > const &
        """
        return _itkClampImageFilterPython.itkClampImageFilterISS3IUC3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::Clamp< short,unsigned char > const &

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS3IUC3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterISS3IUC3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterISS3IUC3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS3IUC3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterISS3IUC3_Superclass

        Create a new object of the class itkClampImageFilterISS3IUC3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterISS3IUC3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterISS3IUC3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterISS3IUC3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterISS3IUC3_Superclass in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterISS3IUC3_Superclass_swigregister(itkClampImageFilterISS3IUC3_Superclass)

def itkClampImageFilterIUC2IF2_Superclass_New():
    return itkClampImageFilterIUC2IF2_Superclass.New()

class itkClampImageFilterIUC2IF2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC2IF2):
    r"""Proxy of C++ itkClampImageFilterIUC2IF2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIUC2IF2_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IF2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIUC2IF2_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IF2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::Clamp< unsigned char,float >
        GetFunctor(self) -> itk::Functor::Clamp< unsigned char,float > const &
        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IF2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::Clamp< unsigned char,float > const &

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IF2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIUC2IF2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIUC2IF2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IF2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIUC2IF2_Superclass

        Create a new object of the class itkClampImageFilterIUC2IF2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIUC2IF2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIUC2IF2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIUC2IF2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIUC2IF2_Superclass in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIUC2IF2_Superclass_swigregister(itkClampImageFilterIUC2IF2_Superclass)

def itkClampImageFilterIUC2ISS2_Superclass_New():
    return itkClampImageFilterIUC2ISS2_Superclass.New()

class itkClampImageFilterIUC2ISS2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC2ISS2):
    r"""Proxy of C++ itkClampImageFilterIUC2ISS2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIUC2ISS2_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC2ISS2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIUC2ISS2_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC2ISS2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::Clamp< unsigned char,short >
        GetFunctor(self) -> itk::Functor::Clamp< unsigned char,short > const &
        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC2ISS2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::Clamp< unsigned char,short > const &

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC2ISS2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIUC2ISS2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIUC2ISS2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC2ISS2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIUC2ISS2_Superclass

        Create a new object of the class itkClampImageFilterIUC2ISS2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIUC2ISS2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIUC2ISS2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIUC2ISS2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIUC2ISS2_Superclass in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIUC2ISS2_Superclass_swigregister(itkClampImageFilterIUC2ISS2_Superclass)

def itkClampImageFilterIUC2IUC2_Superclass_New():
    return itkClampImageFilterIUC2IUC2_Superclass.New()

class itkClampImageFilterIUC2IUC2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC2IUC2):
    r"""Proxy of C++ itkClampImageFilterIUC2IUC2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIUC2IUC2_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IUC2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIUC2IUC2_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IUC2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::Clamp< unsigned char >
        GetFunctor(self) -> itk::Functor::Clamp< unsigned char > const &
        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IUC2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::Clamp< unsigned char > const &

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IUC2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIUC2IUC2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIUC2IUC2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IUC2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIUC2IUC2_Superclass

        Create a new object of the class itkClampImageFilterIUC2IUC2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIUC2IUC2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIUC2IUC2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIUC2IUC2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIUC2IUC2_Superclass in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIUC2IUC2_Superclass_swigregister(itkClampImageFilterIUC2IUC2_Superclass)

def itkClampImageFilterIUC3IF3_Superclass_New():
    return itkClampImageFilterIUC3IF3_Superclass.New()

class itkClampImageFilterIUC3IF3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC3IF3):
    r"""Proxy of C++ itkClampImageFilterIUC3IF3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIUC3IF3_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IF3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIUC3IF3_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IF3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::Clamp< unsigned char,float >
        GetFunctor(self) -> itk::Functor::Clamp< unsigned char,float > const &
        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IF3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::Clamp< unsigned char,float > const &

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IF3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIUC3IF3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIUC3IF3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IF3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIUC3IF3_Superclass

        Create a new object of the class itkClampImageFilterIUC3IF3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIUC3IF3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIUC3IF3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIUC3IF3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIUC3IF3_Superclass in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIUC3IF3_Superclass_swigregister(itkClampImageFilterIUC3IF3_Superclass)

def itkClampImageFilterIUC3ISS3_Superclass_New():
    return itkClampImageFilterIUC3ISS3_Superclass.New()

class itkClampImageFilterIUC3ISS3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC3ISS3):
    r"""Proxy of C++ itkClampImageFilterIUC3ISS3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIUC3ISS3_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC3ISS3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIUC3ISS3_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC3ISS3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::Clamp< unsigned char,short >
        GetFunctor(self) -> itk::Functor::Clamp< unsigned char,short > const &
        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC3ISS3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::Clamp< unsigned char,short > const &

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC3ISS3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIUC3ISS3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIUC3ISS3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC3ISS3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIUC3ISS3_Superclass

        Create a new object of the class itkClampImageFilterIUC3ISS3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIUC3ISS3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIUC3ISS3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIUC3ISS3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIUC3ISS3_Superclass in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIUC3ISS3_Superclass_swigregister(itkClampImageFilterIUC3ISS3_Superclass)

def itkClampImageFilterIUC3IUC3_Superclass_New():
    return itkClampImageFilterIUC3IUC3_Superclass.New()

class itkClampImageFilterIUC3IUC3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC3IUC3):
    r"""Proxy of C++ itkClampImageFilterIUC3IUC3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIUC3IUC3_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IUC3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIUC3IUC3_Superclass_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IUC3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::Clamp< unsigned char >
        GetFunctor(self) -> itk::Functor::Clamp< unsigned char > const &
        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IUC3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::Clamp< unsigned char > const &

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IUC3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIUC3IUC3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIUC3IUC3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IUC3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIUC3IUC3_Superclass

        Create a new object of the class itkClampImageFilterIUC3IUC3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIUC3IUC3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIUC3IUC3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIUC3IUC3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIUC3IUC3_Superclass in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIUC3IUC3_Superclass_swigregister(itkClampImageFilterIUC3IUC3_Superclass)

def itkClampImageFilterIF2IF2_New():
    return itkClampImageFilterIF2IF2.New()

class itkClampImageFilterIF2IF2(itkClampImageFilterIF2IF2_Superclass):
    r"""Proxy of C++ itkClampImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIF2IF2_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIF2IF2_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF2IF2_Clone(self)

    def GetLowerBound(self):
        r"""GetLowerBound(self) -> float"""
        return _itkClampImageFilterPython.itkClampImageFilterIF2IF2_GetLowerBound(self)

    def GetUpperBound(self):
        r"""GetUpperBound(self) -> float"""
        return _itkClampImageFilterPython.itkClampImageFilterIF2IF2_GetUpperBound(self)

    def SetBounds(self, lowerBound, upperBound):
        r"""
        SetBounds(self, lowerBound, upperBound)

        Parameters
        ----------
        lowerBound: float const
        upperBound: float const

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF2IF2_SetBounds(self, lowerBound, upperBound)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIF2IF2

        Create a new object of the class itkClampImageFilterIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIF2IF2 in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIF2IF2_swigregister(itkClampImageFilterIF2IF2)

def itkClampImageFilterIF2ISS2_New():
    return itkClampImageFilterIF2ISS2.New()

class itkClampImageFilterIF2ISS2(itkClampImageFilterIF2ISS2_Superclass):
    r"""Proxy of C++ itkClampImageFilterIF2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIF2ISS2_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIF2ISS2_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF2ISS2_Clone(self)

    def GetLowerBound(self):
        r"""GetLowerBound(self) -> short"""
        return _itkClampImageFilterPython.itkClampImageFilterIF2ISS2_GetLowerBound(self)

    def GetUpperBound(self):
        r"""GetUpperBound(self) -> short"""
        return _itkClampImageFilterPython.itkClampImageFilterIF2ISS2_GetUpperBound(self)

    def SetBounds(self, lowerBound, upperBound):
        r"""
        SetBounds(self, lowerBound, upperBound)

        Parameters
        ----------
        lowerBound: short const
        upperBound: short const

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF2ISS2_SetBounds(self, lowerBound, upperBound)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIF2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIF2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIF2ISS2

        Create a new object of the class itkClampImageFilterIF2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIF2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIF2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIF2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIF2ISS2 in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIF2ISS2_swigregister(itkClampImageFilterIF2ISS2)

def itkClampImageFilterIF2IUC2_New():
    return itkClampImageFilterIF2IUC2.New()

class itkClampImageFilterIF2IUC2(itkClampImageFilterIF2IUC2_Superclass):
    r"""Proxy of C++ itkClampImageFilterIF2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIF2IUC2_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIF2IUC2_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF2IUC2_Clone(self)

    def GetLowerBound(self):
        r"""GetLowerBound(self) -> unsigned char"""
        return _itkClampImageFilterPython.itkClampImageFilterIF2IUC2_GetLowerBound(self)

    def GetUpperBound(self):
        r"""GetUpperBound(self) -> unsigned char"""
        return _itkClampImageFilterPython.itkClampImageFilterIF2IUC2_GetUpperBound(self)

    def SetBounds(self, lowerBound, upperBound):
        r"""
        SetBounds(self, lowerBound, upperBound)

        Parameters
        ----------
        lowerBound: unsigned char const
        upperBound: unsigned char const

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF2IUC2_SetBounds(self, lowerBound, upperBound)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIF2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIF2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIF2IUC2

        Create a new object of the class itkClampImageFilterIF2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIF2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIF2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIF2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIF2IUC2 in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIF2IUC2_swigregister(itkClampImageFilterIF2IUC2)

def itkClampImageFilterIF3IF3_New():
    return itkClampImageFilterIF3IF3.New()

class itkClampImageFilterIF3IF3(itkClampImageFilterIF3IF3_Superclass):
    r"""Proxy of C++ itkClampImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIF3IF3_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIF3IF3_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF3IF3_Clone(self)

    def GetLowerBound(self):
        r"""GetLowerBound(self) -> float"""
        return _itkClampImageFilterPython.itkClampImageFilterIF3IF3_GetLowerBound(self)

    def GetUpperBound(self):
        r"""GetUpperBound(self) -> float"""
        return _itkClampImageFilterPython.itkClampImageFilterIF3IF3_GetUpperBound(self)

    def SetBounds(self, lowerBound, upperBound):
        r"""
        SetBounds(self, lowerBound, upperBound)

        Parameters
        ----------
        lowerBound: float const
        upperBound: float const

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF3IF3_SetBounds(self, lowerBound, upperBound)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIF3IF3

        Create a new object of the class itkClampImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIF3IF3 in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIF3IF3_swigregister(itkClampImageFilterIF3IF3)

def itkClampImageFilterIF3ISS3_New():
    return itkClampImageFilterIF3ISS3.New()

class itkClampImageFilterIF3ISS3(itkClampImageFilterIF3ISS3_Superclass):
    r"""Proxy of C++ itkClampImageFilterIF3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIF3ISS3_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIF3ISS3_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF3ISS3_Clone(self)

    def GetLowerBound(self):
        r"""GetLowerBound(self) -> short"""
        return _itkClampImageFilterPython.itkClampImageFilterIF3ISS3_GetLowerBound(self)

    def GetUpperBound(self):
        r"""GetUpperBound(self) -> short"""
        return _itkClampImageFilterPython.itkClampImageFilterIF3ISS3_GetUpperBound(self)

    def SetBounds(self, lowerBound, upperBound):
        r"""
        SetBounds(self, lowerBound, upperBound)

        Parameters
        ----------
        lowerBound: short const
        upperBound: short const

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF3ISS3_SetBounds(self, lowerBound, upperBound)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIF3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIF3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIF3ISS3

        Create a new object of the class itkClampImageFilterIF3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIF3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIF3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIF3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIF3ISS3 in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIF3ISS3_swigregister(itkClampImageFilterIF3ISS3)

def itkClampImageFilterIF3IUC3_New():
    return itkClampImageFilterIF3IUC3.New()

class itkClampImageFilterIF3IUC3(itkClampImageFilterIF3IUC3_Superclass):
    r"""Proxy of C++ itkClampImageFilterIF3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIF3IUC3_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIF3IUC3_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIF3IUC3_Clone(self)

    def GetLowerBound(self):
        r"""GetLowerBound(self) -> unsigned char"""
        return _itkClampImageFilterPython.itkClampImageFilterIF3IUC3_GetLowerBound(self)

    def GetUpperBound(self):
        r"""GetUpperBound(self) -> unsigned char"""
        return _itkClampImageFilterPython.itkClampImageFilterIF3IUC3_GetUpperBound(self)

    def SetBounds(self, lowerBound, upperBound):
        r"""
        SetBounds(self, lowerBound, upperBound)

        Parameters
        ----------
        lowerBound: unsigned char const
        upperBound: unsigned char const

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF3IUC3_SetBounds(self, lowerBound, upperBound)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIF3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIF3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIF3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIF3IUC3

        Create a new object of the class itkClampImageFilterIF3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIF3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIF3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIF3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIF3IUC3 in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIF3IUC3_swigregister(itkClampImageFilterIF3IUC3)

def itkClampImageFilterISS2IF2_New():
    return itkClampImageFilterISS2IF2.New()

class itkClampImageFilterISS2IF2(itkClampImageFilterISS2IF2_Superclass):
    r"""Proxy of C++ itkClampImageFilterISS2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterISS2IF2_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterISS2IF2_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS2IF2_Clone(self)

    def GetLowerBound(self):
        r"""GetLowerBound(self) -> float"""
        return _itkClampImageFilterPython.itkClampImageFilterISS2IF2_GetLowerBound(self)

    def GetUpperBound(self):
        r"""GetUpperBound(self) -> float"""
        return _itkClampImageFilterPython.itkClampImageFilterISS2IF2_GetUpperBound(self)

    def SetBounds(self, lowerBound, upperBound):
        r"""
        SetBounds(self, lowerBound, upperBound)

        Parameters
        ----------
        lowerBound: float const
        upperBound: float const

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS2IF2_SetBounds(self, lowerBound, upperBound)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterISS2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterISS2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterISS2IF2

        Create a new object of the class itkClampImageFilterISS2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterISS2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterISS2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterISS2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterISS2IF2 in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterISS2IF2_swigregister(itkClampImageFilterISS2IF2)

def itkClampImageFilterISS2ISS2_New():
    return itkClampImageFilterISS2ISS2.New()

class itkClampImageFilterISS2ISS2(itkClampImageFilterISS2ISS2_Superclass):
    r"""Proxy of C++ itkClampImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterISS2ISS2_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterISS2ISS2_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS2ISS2_Clone(self)

    def GetLowerBound(self):
        r"""GetLowerBound(self) -> short"""
        return _itkClampImageFilterPython.itkClampImageFilterISS2ISS2_GetLowerBound(self)

    def GetUpperBound(self):
        r"""GetUpperBound(self) -> short"""
        return _itkClampImageFilterPython.itkClampImageFilterISS2ISS2_GetUpperBound(self)

    def SetBounds(self, lowerBound, upperBound):
        r"""
        SetBounds(self, lowerBound, upperBound)

        Parameters
        ----------
        lowerBound: short const
        upperBound: short const

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS2ISS2_SetBounds(self, lowerBound, upperBound)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterISS2ISS2

        Create a new object of the class itkClampImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterISS2ISS2 in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterISS2ISS2_swigregister(itkClampImageFilterISS2ISS2)

def itkClampImageFilterISS2IUC2_New():
    return itkClampImageFilterISS2IUC2.New()

class itkClampImageFilterISS2IUC2(itkClampImageFilterISS2IUC2_Superclass):
    r"""Proxy of C++ itkClampImageFilterISS2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterISS2IUC2_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterISS2IUC2_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS2IUC2_Clone(self)

    def GetLowerBound(self):
        r"""GetLowerBound(self) -> unsigned char"""
        return _itkClampImageFilterPython.itkClampImageFilterISS2IUC2_GetLowerBound(self)

    def GetUpperBound(self):
        r"""GetUpperBound(self) -> unsigned char"""
        return _itkClampImageFilterPython.itkClampImageFilterISS2IUC2_GetUpperBound(self)

    def SetBounds(self, lowerBound, upperBound):
        r"""
        SetBounds(self, lowerBound, upperBound)

        Parameters
        ----------
        lowerBound: unsigned char const
        upperBound: unsigned char const

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS2IUC2_SetBounds(self, lowerBound, upperBound)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterISS2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterISS2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterISS2IUC2

        Create a new object of the class itkClampImageFilterISS2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterISS2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterISS2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterISS2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterISS2IUC2 in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterISS2IUC2_swigregister(itkClampImageFilterISS2IUC2)

def itkClampImageFilterISS3IF3_New():
    return itkClampImageFilterISS3IF3.New()

class itkClampImageFilterISS3IF3(itkClampImageFilterISS3IF3_Superclass):
    r"""Proxy of C++ itkClampImageFilterISS3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterISS3IF3_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterISS3IF3_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS3IF3_Clone(self)

    def GetLowerBound(self):
        r"""GetLowerBound(self) -> float"""
        return _itkClampImageFilterPython.itkClampImageFilterISS3IF3_GetLowerBound(self)

    def GetUpperBound(self):
        r"""GetUpperBound(self) -> float"""
        return _itkClampImageFilterPython.itkClampImageFilterISS3IF3_GetUpperBound(self)

    def SetBounds(self, lowerBound, upperBound):
        r"""
        SetBounds(self, lowerBound, upperBound)

        Parameters
        ----------
        lowerBound: float const
        upperBound: float const

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS3IF3_SetBounds(self, lowerBound, upperBound)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterISS3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterISS3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterISS3IF3

        Create a new object of the class itkClampImageFilterISS3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterISS3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterISS3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterISS3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterISS3IF3 in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterISS3IF3_swigregister(itkClampImageFilterISS3IF3)

def itkClampImageFilterISS3ISS3_New():
    return itkClampImageFilterISS3ISS3.New()

class itkClampImageFilterISS3ISS3(itkClampImageFilterISS3ISS3_Superclass):
    r"""Proxy of C++ itkClampImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterISS3ISS3_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterISS3ISS3_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS3ISS3_Clone(self)

    def GetLowerBound(self):
        r"""GetLowerBound(self) -> short"""
        return _itkClampImageFilterPython.itkClampImageFilterISS3ISS3_GetLowerBound(self)

    def GetUpperBound(self):
        r"""GetUpperBound(self) -> short"""
        return _itkClampImageFilterPython.itkClampImageFilterISS3ISS3_GetUpperBound(self)

    def SetBounds(self, lowerBound, upperBound):
        r"""
        SetBounds(self, lowerBound, upperBound)

        Parameters
        ----------
        lowerBound: short const
        upperBound: short const

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS3ISS3_SetBounds(self, lowerBound, upperBound)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterISS3ISS3

        Create a new object of the class itkClampImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterISS3ISS3 in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterISS3ISS3_swigregister(itkClampImageFilterISS3ISS3)

def itkClampImageFilterISS3IUC3_New():
    return itkClampImageFilterISS3IUC3.New()

class itkClampImageFilterISS3IUC3(itkClampImageFilterISS3IUC3_Superclass):
    r"""Proxy of C++ itkClampImageFilterISS3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterISS3IUC3_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterISS3IUC3_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterISS3IUC3_Clone(self)

    def GetLowerBound(self):
        r"""GetLowerBound(self) -> unsigned char"""
        return _itkClampImageFilterPython.itkClampImageFilterISS3IUC3_GetLowerBound(self)

    def GetUpperBound(self):
        r"""GetUpperBound(self) -> unsigned char"""
        return _itkClampImageFilterPython.itkClampImageFilterISS3IUC3_GetUpperBound(self)

    def SetBounds(self, lowerBound, upperBound):
        r"""
        SetBounds(self, lowerBound, upperBound)

        Parameters
        ----------
        lowerBound: unsigned char const
        upperBound: unsigned char const

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS3IUC3_SetBounds(self, lowerBound, upperBound)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterISS3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterISS3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterISS3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterISS3IUC3

        Create a new object of the class itkClampImageFilterISS3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterISS3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterISS3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterISS3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterISS3IUC3 in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterISS3IUC3_swigregister(itkClampImageFilterISS3IUC3)

def itkClampImageFilterIUC2IF2_New():
    return itkClampImageFilterIUC2IF2.New()

class itkClampImageFilterIUC2IF2(itkClampImageFilterIUC2IF2_Superclass):
    r"""Proxy of C++ itkClampImageFilterIUC2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIUC2IF2_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIUC2IF2_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IF2_Clone(self)

    def GetLowerBound(self):
        r"""GetLowerBound(self) -> float"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IF2_GetLowerBound(self)

    def GetUpperBound(self):
        r"""GetUpperBound(self) -> float"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IF2_GetUpperBound(self)

    def SetBounds(self, lowerBound, upperBound):
        r"""
        SetBounds(self, lowerBound, upperBound)

        Parameters
        ----------
        lowerBound: float const
        upperBound: float const

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IF2_SetBounds(self, lowerBound, upperBound)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIUC2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIUC2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIUC2IF2

        Create a new object of the class itkClampImageFilterIUC2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIUC2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIUC2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIUC2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIUC2IF2 in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIUC2IF2_swigregister(itkClampImageFilterIUC2IF2)

def itkClampImageFilterIUC2ISS2_New():
    return itkClampImageFilterIUC2ISS2.New()

class itkClampImageFilterIUC2ISS2(itkClampImageFilterIUC2ISS2_Superclass):
    r"""Proxy of C++ itkClampImageFilterIUC2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIUC2ISS2_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIUC2ISS2_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC2ISS2_Clone(self)

    def GetLowerBound(self):
        r"""GetLowerBound(self) -> short"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC2ISS2_GetLowerBound(self)

    def GetUpperBound(self):
        r"""GetUpperBound(self) -> short"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC2ISS2_GetUpperBound(self)

    def SetBounds(self, lowerBound, upperBound):
        r"""
        SetBounds(self, lowerBound, upperBound)

        Parameters
        ----------
        lowerBound: short const
        upperBound: short const

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC2ISS2_SetBounds(self, lowerBound, upperBound)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIUC2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIUC2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIUC2ISS2

        Create a new object of the class itkClampImageFilterIUC2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIUC2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIUC2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIUC2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIUC2ISS2 in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIUC2ISS2_swigregister(itkClampImageFilterIUC2ISS2)

def itkClampImageFilterIUC2IUC2_New():
    return itkClampImageFilterIUC2IUC2.New()

class itkClampImageFilterIUC2IUC2(itkClampImageFilterIUC2IUC2_Superclass):
    r"""Proxy of C++ itkClampImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIUC2IUC2_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIUC2IUC2_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IUC2_Clone(self)

    def GetLowerBound(self):
        r"""GetLowerBound(self) -> unsigned char"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IUC2_GetLowerBound(self)

    def GetUpperBound(self):
        r"""GetUpperBound(self) -> unsigned char"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IUC2_GetUpperBound(self)

    def SetBounds(self, lowerBound, upperBound):
        r"""
        SetBounds(self, lowerBound, upperBound)

        Parameters
        ----------
        lowerBound: unsigned char const
        upperBound: unsigned char const

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IUC2_SetBounds(self, lowerBound, upperBound)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIUC2IUC2

        Create a new object of the class itkClampImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIUC2IUC2 in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIUC2IUC2_swigregister(itkClampImageFilterIUC2IUC2)

def itkClampImageFilterIUC3IF3_New():
    return itkClampImageFilterIUC3IF3.New()

class itkClampImageFilterIUC3IF3(itkClampImageFilterIUC3IF3_Superclass):
    r"""Proxy of C++ itkClampImageFilterIUC3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIUC3IF3_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIUC3IF3_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IF3_Clone(self)

    def GetLowerBound(self):
        r"""GetLowerBound(self) -> float"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IF3_GetLowerBound(self)

    def GetUpperBound(self):
        r"""GetUpperBound(self) -> float"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IF3_GetUpperBound(self)

    def SetBounds(self, lowerBound, upperBound):
        r"""
        SetBounds(self, lowerBound, upperBound)

        Parameters
        ----------
        lowerBound: float const
        upperBound: float const

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IF3_SetBounds(self, lowerBound, upperBound)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIUC3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIUC3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIUC3IF3

        Create a new object of the class itkClampImageFilterIUC3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIUC3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIUC3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIUC3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIUC3IF3 in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIUC3IF3_swigregister(itkClampImageFilterIUC3IF3)

def itkClampImageFilterIUC3ISS3_New():
    return itkClampImageFilterIUC3ISS3.New()

class itkClampImageFilterIUC3ISS3(itkClampImageFilterIUC3ISS3_Superclass):
    r"""Proxy of C++ itkClampImageFilterIUC3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIUC3ISS3_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIUC3ISS3_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC3ISS3_Clone(self)

    def GetLowerBound(self):
        r"""GetLowerBound(self) -> short"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC3ISS3_GetLowerBound(self)

    def GetUpperBound(self):
        r"""GetUpperBound(self) -> short"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC3ISS3_GetUpperBound(self)

    def SetBounds(self, lowerBound, upperBound):
        r"""
        SetBounds(self, lowerBound, upperBound)

        Parameters
        ----------
        lowerBound: short const
        upperBound: short const

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC3ISS3_SetBounds(self, lowerBound, upperBound)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIUC3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIUC3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIUC3ISS3

        Create a new object of the class itkClampImageFilterIUC3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIUC3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIUC3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIUC3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIUC3ISS3 in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIUC3ISS3_swigregister(itkClampImageFilterIUC3ISS3)

def itkClampImageFilterIUC3IUC3_New():
    return itkClampImageFilterIUC3IUC3.New()

class itkClampImageFilterIUC3IUC3(itkClampImageFilterIUC3IUC3_Superclass):
    r"""Proxy of C++ itkClampImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkClampImageFilterIUC3IUC3_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkClampImageFilterIUC3IUC3_Pointer"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IUC3_Clone(self)

    def GetLowerBound(self):
        r"""GetLowerBound(self) -> unsigned char"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IUC3_GetLowerBound(self)

    def GetUpperBound(self):
        r"""GetUpperBound(self) -> unsigned char"""
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IUC3_GetUpperBound(self)

    def SetBounds(self, lowerBound, upperBound):
        r"""
        SetBounds(self, lowerBound, upperBound)

        Parameters
        ----------
        lowerBound: unsigned char const
        upperBound: unsigned char const

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IUC3_SetBounds(self, lowerBound, upperBound)
    __swig_destroy__ = _itkClampImageFilterPython.delete_itkClampImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkClampImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkClampImageFilterPython.itkClampImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkClampImageFilterIUC3IUC3

        Create a new object of the class itkClampImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkClampImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkClampImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkClampImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkClampImageFilterIUC3IUC3 in _itkClampImageFilterPython:
_itkClampImageFilterPython.itkClampImageFilterIUC3IUC3_swigregister(itkClampImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def clamp_image_filter(*args: itkt.ImageLike,  bounds: int=..., functor=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for ClampImageFilter"""
    import itk

    kwarg_typehints = { 'bounds':bounds,'functor':functor }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.ClampImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def clamp_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageIntensity.ClampImageFilter
    clamp_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    clamp_image_filter.__doc__ = filter_object.__doc__

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def unary_functor_image_filter(*args: itkt.ImageLike,  functor=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for UnaryFunctorImageFilter"""
    import itk

    kwarg_typehints = { 'functor':functor }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.UnaryFunctorImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def unary_functor_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageIntensity.UnaryFunctorImageFilter
    unary_functor_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    unary_functor_image_filter.__doc__ = filter_object.__doc__



